/**
 * Copyright 2014 Red Hat, Inc.
 *
 * This software is licensed to you under the GNU General Public
 * License as published by the Free Software Foundation; either version
 * 2 of the License (GPLv2) or (at your option) any later version.
 * There is NO WARRANTY for this software, express or implied,
 * including the implied warranties of MERCHANTABILITY,
 * NON-INFRINGEMENT, or FITNESS FOR A PARTICULAR PURPOSE. You should
 * have received a copy of GPLv2 along with this software; if not, see
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.
 */

/**
 * @ngdoc object
 * @name  Bastion.content-hosts.controller:ContentHostsBulkActionEnvironmentController
 *
 * @requires $scope
 * @requires ContentHostBulkAction
 * @requires Organization
 * @requires CurrentOrganization
 * @requires ContentView
 *
 * @description
 *   A controller for providing bulk action functionality for setting content view and environment
 */
angular.module('Bastion.content-hosts').controller('ContentHostsBulkActionEnvironmentController',
    ['$scope', 'ContentHostBulkAction', 'Organization', 'CurrentOrganization', 'ContentView',
    function ($scope, ContentHostBulkAction, Organization, CurrentOrganization, ContentView) {

        $scope.setState(false, [], []);
        $scope.selected = {
            environment: undefined,
            contentView: undefined
        };

        $scope.environments = Organization.readableEnvironments({id: CurrentOrganization});

        $scope.disableAssignButton = function (confirm) {
            return confirm || $scope.table.numSelected === 0 || $scope.state.working ||
                $scope.selected.environment === undefined || $scope.selected.contentView === undefined;
        };

        $scope.$watch('selected.environment', function (environment) {
            if (environment) {
                $scope.fetchViews();
            }
        });

        $scope.fetchViews = function () {
            $scope.fetchingContentViews = true;

            ContentView.queryUnpaged({ 'environment_id': $scope.selected.environment.id }, function (response) {
                $scope.contentViews = response.results;
                $scope.fetchingContentViews = false;
            });
        };

        $scope.performAction = function () {
            $scope.setState(true, [], []);

            ContentHostBulkAction.environmentContentView(actionParams(), function (response) {
                $scope.setState(false, response.displayMessages.success, response.displayMessages.error);
            }, function (data) {
                $scope.setState(false, [], data.errors);
            });
        };

        function actionParams() {
            var params = $scope.nutupane.getAllSelectedResults();
            params['organization_id'] = CurrentOrganization;
            params['environment_id'] = $scope.selected.environment.id;
            params['content_view_id'] = $scope.selected.contentView.id;
            return params;
        }
    }]
);
